==> eslint_5.0.1~dfsg.orig.tar.xz: eslint-5.0.1/tests/lib/rules/no-unsafe-negation.js <==
/**
 * @fileoverview Tests for no-unsafe-negation rule.
 * @author Toru Nagashima
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/no-unsafe-negation"),
    RuleTester = require("../../../lib/testers/rule-tester");

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester();

ruleTester.run("no-unsafe-negation", rule, {
    valid: [
        "a in b",
        "a in b === false",
        "!(a in b)",
        "(!a) in b",
        "a instanceof b",
        "a instanceof b === false",
        "!(a instanceof b)",
        "(!a) instanceof b"
    ],
    invalid: [
        {
            code: "!a in b",
            output: "!(a in b)",
            errors: ["Unexpected negating the left operand of 'in' operator."]
        },
        {
            code: "(!a in b)",
            output: "(!(a in b))",
            errors: ["Unexpected negating the left operand of 'in' operator."]
        },
        {
            code: "!(a) in b",
            output: "!((a) in b)",
            errors: ["Unexpected negating the left operand of 'in' operator."]
        },
        {
            code: "!a instanceof b",
            output: "!(a instanceof b)",
            errors: ["Unexpected negating the left operand of 'instanceof' operator."]
        },
        {
            code: "(!a instanceof b)",
            output: "(!(a instanceof b))",
            errors: ["Unexpected negating the left operand of 'instanceof' operator."]
        },
        {
            code: "!(a) instanceof b",
            output: "!((a) instanceof b)",
            errors: ["Unexpected negating the left operand of 'instanceof' operator."]
        }
    ]
});

==> eslint_5.16.0~dfsg+~4.16.8.orig.tar.xz: eslint-5.16.0/tests/lib/rules/no-unsafe-negation.js <==
/**
 * @fileoverview Tests for no-unsafe-negation rule.
 * @author Toru Nagashima
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/no-unsafe-negation"),
    RuleTester = require("../../../lib/testers/rule-tester");

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester();
const unexpectedInError = { messageId: "unexpected", data: { operator: "in" } };
const unexpectedInstanceofError = { messageId: "unexpected", data: { operator: "instanceof" } };

ruleTester.run("no-unsafe-negation", rule, {
    valid: [
        "a in b",
        "a in b === false",
        "!(a in b)",
        "(!a) in b",
        "a instanceof b",
        "a instanceof b === false",
        "!(a instanceof b)",
        "(!a) instanceof b"
    ],
    invalid: [
        {
            code: "!a in b",
            output: "!(a in b)",
            errors: [unexpectedInError]
        },
        {
            code: "(!a in b)",
            output: "(!(a in b))",
            errors: [unexpectedInError]
        },
        {
            code: "!(a) in b",
            output: "!((a) in b)",
            errors: [unexpectedInError]
        },
        {
            code: "!a instanceof b",
            output: "!(a instanceof b)",
            errors: [unexpectedInstanceofError]
        },
        {
            code: "(!a instanceof b)",
            output: "(!(a instanceof b))",
            errors: [unexpectedInstanceofError]
        },
        {
            code: "!(a) instanceof b",
            output: "!((a) instanceof b)",
            errors: [unexpectedInstanceofError]
        }
    ]
});
